

CREATE OR REPLACE FUNCTION spFix_BiayaAtasPurc_Ditagih()
RETURNS SETOF SPStatus AS 
$BODY$
DECLARE
	_retval		SPStatus%ROWTYPE;

	cData		REFCURSOR;

	_PurcNo		purc.purcno%TYPE;
	_ExcRate	NUMERIC(19,4);
	_Total		NUMERIC(19,4);
	_BaseTotal	NUMERIC(19,4);
	_DueDays	INT2;
	_BPId		bp.bpid%TYPE;
	_CrcId		crc.crcid%TYPE;
BEGIN
	_retval:=(0, 'OK');

	OPEN cData FOR
		SELECT purcno, total, basetotal, excrate 
		FROM purc 
		WHERE reftype='PURC' AND refno IS NOT NULL;
	LOOP
		FETCH cData INTO _PurcNo, _Total, _BaseTotal;
		EXIT WHEN NOT FOUND;

		SELECT INTO _BPId, _CrcId vendorid, crcid FROM purc WHERE purcno=_PurcNo;
		SELECT INTO _DueDays apduedays FROM bpacc WHERE bpid=_BPId AND crcid=_CrcId;

		_DueDays:=COALESCE(_DueDays, 14);

		IF (_ExcRate=1) THEN
			UPDATE purc SET duedays=_DueDays WHERE purcno=_PurcNo;
		ELSE
			UPDATE purc SET total=_BaseTotal, basetotal=_Total, duedays=_DueDays WHERE purcno=_PurcNo;
		END IF;
	END LOOP;
	CLOSE cData;

	RETURN NEXT _retval;
END;
$BODY$
LANGUAGE 'plpgsql' VOLATILE;


SELECT * FROM spFix_BiayaAtasPurc_Ditagih();



DROP FUNCTION spCreatePurcTransCost(VARCHAR, DATE, VARCHAR, VARCHAR, VARCHAR, VARCHAR, NUMERIC, NUMERIC, NUMERIC, NUMERIC, TEXT);
CREATE OR REPLACE FUNCTION spCreatePurcTransCost(
	_P_PurcNo	purc.purcno%TYPE,
	_P_PurcDate	DATE,
	_P_VendorId	bp.bpid%TYPE,
	_P_TermType	purc.termtype%TYPE,
	_P_AccAP	acc.accno%TYPE,
	_P_CrcId	crc.crcid%TYPE,
	_P_ExcRate	NUMERIC(19,4),
	_P_FisRate	NUMERIC(19,4),
	_P_BTotal	NUMERIC(19,4),
	_P_Total	NUMERIC(19,4),
	_P_CostNote	TEXT
) RETURNS SETOF SPStatus AS 
$BODY$
DECLARE
	_retval		SPStatus%ROWTYPE;
	_spret		SPStatus%ROWTYPE;

	_PurcNo		purc.purcno%TYPE;
	_RefType	reftype.reftype%TYPE;
	_DueDays	INT2;
BEGIN
	_retval:=(0, 'OK');

	SELECT INTO _DueDays apduedays 
	FROM bpacc WHERE bpid=_P_VendorId AND crcid=_P_CrcId;
	IF NOT FOUND THEN
		_retval.ErrNo:=50555;
		_retval.ErrMsg:='Mata uang '||_P_CrcId||' belum diset untuk mitra bisnis#'||_P_VendorId;
		RAISE EXCEPTION '%', _retval.ErrMsg;
	END IF;

	_DueDays:=COALESCE(_DueDays, 14);

	_PurcNo:=fTransNoGet('PURCX');
	INSERT INTO purc (purctype, vendorid, purcdate, purcno, _xt, reftype, refno, crcid, excrate, fisrate, total, basetotal, termtype, accap, purcnote, duedays)
		VALUES ('P', _P_VendorId, _P_PurcDate, _PurcNo, TRUE, 'PURC', _P_PurcNo, _P_CrcId, _P_ExcRate, _P_FisRate, _P_Total, _P_BTotal, _P_TermType, _P_AccAP, 'Biaya atas Pembelian#'||_P_PurcNo||E'\n'||_P_CostNote, _DueDays);

	RETURN NEXT _retval;
END;
$BODY$
LANGUAGE 'plpgsql' VOLATILE;


